@@ -2,7 +2,7 @@ package load;
 
 # Make sure we have version info for this module
 
-$VERSION  = '0.13';
+$VERSION  = '0.14';
 
 #--------------------------------------------------------------------------
 # No, we're NOT using strict here.  There are several reasons, the most
@@ -597,6 +597,10 @@ class to be used, thereby accessing the "load" pragma automagically (and hence
 the naming of the keyword of course).  See also the L<autoload> keyword to
 have the module use the generic AUTOLOAD subroutine.
 
+=head1 REQUIRED MODULES
+
+ (none)
+
 =head1 DIFFERENCES WITH SIMILAR MODULES
 
 There are a number of (core) modules that more or less do the same thing as
